@@ -21,7 +21,6 @@ import sys
 import logging
 from os import path
 from types import GeneratorType
-import collections
 
 if sys.version_info[0] >= 3:
     from pickle import _Unpickler as Unpickler
@@ -138,7 +137,7 @@ class NewUnpickler(Unpickler):
         # Execute object's initialize to setup the generators.
         for obj in self.objects:
             if hasattr(obj, '__initialize__') and \
-                   isinstance(obj.__initialize__, collections.Callable):
+                   callable(obj.__initialize__):
                 ret = obj.__initialize__()
                 if isinstance(ret, GeneratorType):
                     generators.append((obj, ret))
